@@ -510,6 +510,7 @@ void BrowseMainPage::updateSortOrder()
 
     d->mDirModel->setSortRole(sortRole);
     d->mDirModel->sort(column, order);
+    d->mGvCore->setTrackFileManagerSorting(false);
 }
 
 void BrowseMainPage::updateThumbnailDetails()
@@ -572,3 +573,5 @@ QToolButton *BrowseMainPage::toggleSideBarButton() const
 }
 
 } // namespace
+
+#include "moc_browsemainpage.cpp"
