@@ -28,7 +28,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 // Local
 #include <lib/document/document.h>
 
-class KAboutData;
 class KPluginMetaData;
 
 namespace Gwenview
@@ -51,7 +50,7 @@ private Q_SLOTS:
     void showJobError(KJob *);
 
 private:
-    DocumentView *mDocumentView;
+    DocumentView *mDocumentView = nullptr;
 };
 
 } // namespace
